==> kubernetes-model-admissionregistration-4.12.0-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/SubjectAccessReviewStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class SubjectAccessReviewStatusFluentImpl<A extends io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatusFluent<A> {

    private Boolean allowed;
    private Boolean denied;
    private String evaluationError;
    private String reason;

    public SubjectAccessReviewStatusFluentImpl() { 
    }


    public SubjectAccessReviewStatusFluentImpl(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatus instance) { 
        this.withAllowed(instance.getAllowed()); 
        this.withDenied(instance.getDenied()); 
        this.withEvaluationError(instance.getEvaluationError()); 
        this.withReason(instance.getReason()); 
    }


    public Boolean isAllowed() {
        return this.allowed;
    }

    public A withAllowed(Boolean allowed) {
        this.allowed=allowed; return (A) this;
    }

    public Boolean hasAllowed() {
        return this.allowed != null;
    }

    public A withNewAllowed(String arg1) {
        return (A)withAllowed(new Boolean(arg1));
    }

    public A withNewAllowed(boolean arg1) {
        return (A)withAllowed(new Boolean(arg1));
    }

    public Boolean isDenied() {
        return this.denied;
    }

    public A withDenied(Boolean denied) {
        this.denied=denied; return (A) this;
    }

    public Boolean hasDenied() {
        return this.denied != null;
    }

    public A withNewDenied(String arg1) {
        return (A)withDenied(new Boolean(arg1));
    }

    public A withNewDenied(boolean arg1) {
        return (A)withDenied(new Boolean(arg1));
    }

    public String getEvaluationError() {
        return this.evaluationError;
    }

    public A withEvaluationError(String evaluationError) {
        this.evaluationError=evaluationError; return (A) this;
    }

    public Boolean hasEvaluationError() {
        return this.evaluationError != null;
    }

    public A withNewEvaluationError(String arg1) {
        return (A)withEvaluationError(new String(arg1));
    }

    public A withNewEvaluationError(StringBuilder arg1) {
        return (A)withEvaluationError(new String(arg1));
    }

    public A withNewEvaluationError(StringBuffer arg1) {
        return (A)withEvaluationError(new String(arg1));
    }

    public String getReason() {
        return this.reason;
    }

    public A withReason(String reason) {
        this.reason=reason; return (A) this;
    }

    public Boolean hasReason() {
        return this.reason != null;
    }

    public A withNewReason(String arg1) {
        return (A)withReason(new String(arg1));
    }

    public A withNewReason(StringBuilder arg1) {
        return (A)withReason(new String(arg1));
    }

    public A withNewReason(StringBuffer arg1) {
        return (A)withReason(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SubjectAccessReviewStatusFluentImpl that = (SubjectAccessReviewStatusFluentImpl) o;
        if (allowed != null ? !allowed.equals(that.allowed) :that.allowed != null) return false;
        if (denied != null ? !denied.equals(that.denied) :that.denied != null) return false;
        if (evaluationError != null ? !evaluationError.equals(that.evaluationError) :that.evaluationError != null) return false;
        if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(allowed,  denied,  evaluationError,  reason,  super.hashCode());
    }

}

==> kubernetes-model-admissionregistration-5.4.1-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/SubjectAccessReviewStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class SubjectAccessReviewStatusFluentImpl<A extends io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatusFluent<A> {

    private java.lang.Boolean allowed;
    private java.lang.Boolean denied;
    private java.lang.String evaluationError;
    private java.lang.String reason;

    public SubjectAccessReviewStatusFluentImpl() {
    }

    public SubjectAccessReviewStatusFluentImpl(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewStatus instance) {
        this.withAllowed(instance.getAllowed()); 
        this.withDenied(instance.getDenied()); 
        this.withEvaluationError(instance.getEvaluationError()); 
        this.withReason(instance.getReason()); 
    }

    public java.lang.Boolean getAllowed() {
        return this.allowed;
    }

    public A withAllowed(java.lang.Boolean allowed) {
        this.allowed=allowed; return (A) this;
    }

    public java.lang.Boolean hasAllowed() {
        return this.allowed != null;
    }

    public java.lang.Boolean getDenied() {
        return this.denied;
    }

    public A withDenied(java.lang.Boolean denied) {
        this.denied=denied; return (A) this;
    }

    public java.lang.Boolean hasDenied() {
        return this.denied != null;
    }

    public java.lang.String getEvaluationError() {
        return this.evaluationError;
    }

    public A withEvaluationError(java.lang.String evaluationError) {
        this.evaluationError=evaluationError; return (A) this;
    }

    public java.lang.Boolean hasEvaluationError() {
        return this.evaluationError != null;
    }

    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withEvaluationError instead.
     */
        public A withNewEvaluationError(java.lang.String arg0) {
        return (A)withEvaluationError(new String(arg0));
    }

    public java.lang.String getReason() {
        return this.reason;
    }

    public A withReason(java.lang.String reason) {
        this.reason=reason; return (A) this;
    }

    public java.lang.Boolean hasReason() {
        return this.reason != null;
    }

    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withReason instead.
     */
        public A withNewReason(java.lang.String arg0) {
        return (A)withReason(new String(arg0));
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SubjectAccessReviewStatusFluentImpl that = (SubjectAccessReviewStatusFluentImpl) o;
        if (allowed != null ? !allowed.equals(that.allowed) :that.allowed != null) return false;
        if (denied != null ? !denied.equals(that.denied) :that.denied != null) return false;
        if (evaluationError != null ? !evaluationError.equals(that.evaluationError) :that.evaluationError != null) return false;
        if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(allowed,  denied,  evaluationError,  reason,  super.hashCode());
    }

}
